@@ -13,8 +13,8 @@ from mako.template import Template
 
 from bcbio import utils
 
-def runner(dirs, config):
-    """Run a set of tasks asynchronously using Celery.
+def runner(dirs, config, config_file, wait=True):
+    """Run a set of tasks using Celery, waiting for results or asynchronously.
 
     This is initialized with the configuration and directory information,
     which is used to prepare a Celery configuration file and imports. It
@@ -27,7 +27,7 @@ def runner(dirs, config):
     ready, returning them.
     """
     task_module = "bcbio.distributed.tasks"
-    with create_celeryconfig(task_module, dirs, config):
+    with create_celeryconfig(task_module, dirs, config, config_file):
         __import__(task_module)
         tasks = sys.modules[task_module]
         from celery.task.sets import TaskSet
@@ -35,12 +35,13 @@ def runner(dirs, config):
             fn = getattr(tasks, fn_name)
             job = TaskSet(tasks=[apply(fn.subtask, (x,)) for x in xs])
             result = job.apply_async()
-            while not result.ready():
-                time.sleep(5)
             out = []
-            for x in result.join():
-                if x:
-                    out.extend(x)
+            if wait:
+                while not result.ready():
+                    time.sleep(5)
+                for x in result.join():
+                    if x:
+                        out.extend(x)
             return out
         return _run
 
@@ -59,11 +60,16 @@ CELERY_TASK_SERIALIZER = "json"
 CELERYD_CONCURRENCY = ${cores}
 CELERY_ACKS_LATE = True
 CELERYD_PREFETCH_MULTIPLIER = 1
+CELERY_ROUTES = {"bcbio.distributed.tasks.analyze_and_upload": {"queue": "toplevel"},
+                 "bcbio.distributed.tasks.long_term_storage" : {"queue": "storage"}}
+BCBIO_CONFIG_FILE = "${config_file}"
 """
 
 @contextlib.contextmanager
-def create_celeryconfig(task_module, dirs, config):
+def create_celeryconfig(task_module, dirs, config, config_file):
     amqp_config = utils.read_galaxy_amqp_config(config["galaxy_config"], dirs["config"])
+    if not amqp_config.has_key("host") or not amqp_config.has_key("userid"):
+        raise ValueError("universe_wsgi.ini does not have RabbitMQ messaging details set")
     out_file = os.path.join(dirs["work"], "celeryconfig.py")
     amqp_config["rabbitmq_vhost"] = config["distributed"]["rabbitmq_vhost"]
     cores = config["distributed"].get("cores_per_host", 0)
@@ -71,6 +77,7 @@ def create_celeryconfig(task_module, dirs, config):
         cores = multiprocessing.cpu_count()
     amqp_config["cores"] = cores
     amqp_config["task_import"] = task_module
+    amqp_config["config_file"] = config_file
     with open(out_file, "w") as out_handle:
         out_handle.write(Template(_celeryconfig_tmpl).render(**amqp_config))
     try:
