@@ -32,20 +32,24 @@ def _run_info_from_yaml(fc_dir, run_info_yaml):
     """
     with open(run_info_yaml) as in_handle:
         loaded = yaml.load(in_handle)
+    fc_name = None
     try:
         fc_name, fc_date = get_flowcell_info(fc_dir)
     except ValueError:
-        if isinstance(loaded, dict):
-            if loaded.has_key("fc_name") and loaded.has_key("fc_date"):
-                fc_name = loaded["fc_name"]
-                fc_date = loaded["fc_date"]
-            loaded = loaded["details"]
-        if fc_name is None:
-            fc_name, fc_date = _unique_flowcell_info()
+        pass
+    if isinstance(loaded, dict):
+        if loaded.has_key("fc_name") and loaded.has_key("fc_date"):
+            fc_name = loaded["fc_name"].replace(" ", "_")
+            fc_date = str(loaded["fc_date"]).replace(" ", "_")
+        loaded = loaded["details"]
+    if fc_name is None:
+        fc_name, fc_date = _unique_flowcell_info()
     run_details = []
     for i, item in enumerate(loaded):
         if not item.has_key("lane"):
             item["lane"] = _generate_lane(item["files"], i)
+        if not item.has_key("description"):
+            item["description"] = str(item["lane"])
         run_details.append(item)
     lanes = [x["lane"] for x in run_details]
     assert len(lanes) == len(set(lanes)), "Non unique lanes: %s" % lanes
@@ -62,6 +66,8 @@ def _generate_lane(fnames, index):
     """
     to_remove = ["s_", "sequence"]
     work_names = []
+    if isinstance(fnames, str):
+        fnames = [fnames]
     for fname in fnames:
         n = os.path.splitext(os.path.basename(fname))[0]
         for r in to_remove:
